[Qa-jenkins-scm] [jenkins.debian.net] 01/01: reproducible: only keep artifacts for 1 day (instead of 2)

Holger Levsen holger at moszumanska.debian.org
Wed Nov 4 10:18:10 UTC 2015


This is an automated email from the git hooks/post-receive script.

holger pushed a commit to branch master
in repository jenkins.debian.net.

commit 5b0a2dc249bd25dbc7a0c8c911f80a7ffc94dcd2
Author: Holger Levsen <holger at layer-acht.org>
Date:   Wed Nov 4 11:17:52 2015 +0100

    reproducible: only keep artifacts for 1 day (instead of 2)
---
 bin/reproducible_build.sh       | 2 +-
 bin/reproducible_maintenance.sh | 8 ++++----
 2 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/bin/reproducible_build.sh b/bin/reproducible_build.sh
index 5e0bf03..6756966 100755
--- a/bin/reproducible_build.sh
+++ b/bin/reproducible_build.sh
@@ -48,7 +48,7 @@ save_artifacts() {
 		mkdir -p $BASE/$ARTIFACTS
 		cp -r $TMPDIR/* $BASE/$ARTIFACTS/
 		echo | tee -a ${RBUILDLOG}
-		local msg="Artifacts from this build have been preserved. They will be available for 48h only, so download them now.\n"
+		local msg="Artifacts from this build have been preserved. They will be available for 24h only, so download them now.\n"
 		msg="${msg}WARNING: You shouldn't trust packages downloaded from this host, they can contain malware or the worst of your fears, packaged nicely in debian format.\n"
 		msg="${msg}If you are not afraid facing your fears while helping the world by investigating reproducible build issues, you can download the artifacts from the following location: $URL\n"
 		printf "$msg" | tee -a $BUILDLOG
diff --git a/bin/reproducible_maintenance.sh b/bin/reproducible_maintenance.sh
index dfa6ea4..50bef4e 100755
--- a/bin/reproducible_maintenance.sh
+++ b/bin/reproducible_maintenance.sh
@@ -317,13 +317,13 @@ if [ ! -z "$PSCALL" ] ; then
 fi
 
 
-# remove artifacts older than 2 days
-echo "$(date -u) - Checking for artifacts older than 2 days."
-ARTIFACTS=$(find $BASE/artifacts/* -maxdepth 1 -type d -mtime +2 -exec ls -lad {} \; 2>/dev/null|| true)
+# remove artifacts older than a day
+echo "$(date -u) - Checking for artifacts older than a day."
+ARTIFACTS=$(find $BASE/artifacts/* -maxdepth 1 -type d -mtime +1 -exec ls -lad {} \; 2>/dev/null|| true)
 if [ ! -z "$ARTIFACTS" ] ; then
 	echo
 	echo "Removed old artifacts:"
-	find $BASE/artifacts/* -maxdepth 1 -type d -mtime +2 -exec rm -rv {} \;
+	find $BASE/artifacts/* -maxdepth 1 -type d -mtime +1 -exec rm -rv {} \;
 	echo
 fi
 

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/qa/jenkins.debian.net.git



More information about the Qa-jenkins-scm mailing list